aboutsummaryrefslogtreecommitdiffstats
path: root/yage/math/matrix.h
diff options
context:
space:
mode:
authorYann Herklotz <ymherklotz@gmail.com>2017-09-22 00:02:59 +0100
committerYann Herklotz <ymherklotz@gmail.com>2017-09-22 00:02:59 +0100
commit5deb18b72a4993a4baf59b7da24a04116eab31e6 (patch)
treec7a1523bed9bf7629b311d63e212957a6ae735be /yage/math/matrix.h
parent34396f0483d94229e3a315e5eeb90c77c1425273 (diff)
parente8208166c67e564fb249aa41e9f8c5e2fa1f2b9a (diff)
downloadYAGE-5deb18b72a4993a4baf59b7da24a04116eab31e6.tar.gz
YAGE-5deb18b72a4993a4baf59b7da24a04116eab31e6.zip
Merge branch 'develop'
Diffstat (limited to 'yage/math/matrix.h')
-rw-r--r--yage/math/matrix.h20
1 files changed, 10 insertions, 10 deletions
diff --git a/yage/math/matrix.h b/yage/math/matrix.h
index 3992acfe..3df1509d 100644
--- a/yage/math/matrix.h
+++ b/yage/math/matrix.h
@@ -6,7 +6,7 @@
* ----------------------------------------------------------------------------
*/
-/** @file
+/** @file
*/
#ifndef YAGE_MATH_MATRIX_H
@@ -27,12 +27,12 @@ class Matrix;
/** @internal Namespace for internal details.
*
- * Detail Namespace
+ * Details Namespace
* ================
*
* This is the namespace used for implementation detail.
*/
-namespace detail
+namespace details
{
/** @internal Internal Row class used by the Matrix class to return the
@@ -68,7 +68,7 @@ public:
}
};
-} // namespace detail
+} // namespace details
/** Base Matrix class used by other similar classes.
*/
@@ -76,7 +76,7 @@ template <int Rows = 4, int Cols = 4, class Type = double>
class Matrix
{
// friended with the row class so that it can access protected member data.
- friend class detail::Row<Rows, Cols, Type>;
+ friend class details::Row<Rows, Cols, Type>;
protected:
/// Vector containing the data of the matrix.
@@ -158,14 +158,14 @@ public:
return ss.str();
}
- detail::Row<Rows, Cols, Type> operator[](int row)
+ details::Row<Rows, Cols, Type> operator[](int row)
{
- return detail::Row<Rows, Cols, Type>(this, row);
+ return details::Row<Rows, Cols, Type>(this, row);
}
- detail::Row<Rows, Cols, Type> operator[](int row) const
+ details::Row<Rows, Cols, Type> operator[](int row) const
{
- return detail::Row<Rows, Cols, Type>((Matrix<Rows, Cols, Type> *)this,
+ return details::Row<Rows, Cols, Type>((Matrix<Rows, Cols, Type> *)this,
row);
}
@@ -27,12 +27,12 @@ class Matrix;
* ================
*
- * This is the namespace used for implementation detail.
+ * This is the namespace used for implementation details.
*/